from ..constructor import *
import sys
from components import *
class Oscar:
	def __init__(self, args):
		if len(args) < 1:
			print "You did not provide a package name: \n Oscar's available packages are: \n bootsrap_form --- \t simple bootstrap form\n materialize_form --- \t simple materialize form" 
		else: 
			self.c = Construct()
			self.arg = args
			self.check_components()

	def check_components(self):
		self.f = self.c.create_file()
		print self.arg
		if self.arg[0] == 'bootstrap_form':
			self.c.create_head(self.f, 'bootstrap')
			b_form(self.f, self.arg)
			self.c.create_bottom(self.f, 'bootstrap')




class b_form:
	def __init__(self, f, arg):
		self.file = f
		if len(arg) > 1:
			self.inputs = arg[1:]
		self.set_values()
		self.create_form()

	def set_values(self):
		self.action = raw_input("Form action?  ")
		self.button = raw_input("Button value?  ")

	def create_form(self):
		self.create_top()
		for x in self.inputs:
			self.create_field_set(x)
		self.create_bottom()

	def create_top(self):
		self.file.write("<body>\n")
		self.file.write("<div class = 'col-lg-6'>\n")
		self.file.write("\t<form action = '" + self.action + "' method = 'post'>\n")
	
	def create_field_set(self,x):
		if ':' in x:
			arr = x.split(":", 1)
			if len(arr) > 0:
				name = arr[0]
				typeOf = arr[1]
			else:
				name = x
				typeOf = 'text'
		else:
			name = x
			typeOf = 'text'
			print "you didn't specify type of input so we will use text"
		label = self.create_label(name)
		self.file.write("\t\t<fieldset class = 'form-group'>\n")				
		self.file.write("\t\t\t<label for='" + name + "'>" + label + "</label>\n")
		self.file.write("\t\t\t<input id = '" + name + "' name = '" + name + "' type = '" + typeOf + "' class='form-control'>\n")
		self.file.write("\t\t</fieldset>\n")
	
	def create_bottom(self):
		self.file.write("\t\t<fieldset class = 'form-group'>\n")
		self.file.write("\t\t\t<input type = 'submit' class = 'btn' value = " + self.button + ">\n")
		self.file.write("\t</fieldset>\n")
		self.file.write("\t</form>\n")
		self.file.write("</div>\n")

	def create_label(self, label):
		l = label.replace('_', ' ')
		la = l.title()
		return la




__version__ = "0.1.5"

import sys
import os
sys.path.append(os.path.dirname(__file__) + "/package_store")
print 'this is the first \n'
print sys.path
from package_store import *

class main:
	def __init__(self):
		if len(sys.argv) > 1:
			self.check_packages()
		else:
			print 'No function called, available packages:\n \toscar'

	def check_packages(self):
		if sys.argv[1] == 'oscar':
			Oscar(sys.argv[2:])


import re
from setuptools import setup, find_packages


version = re.search(
   '^__version__\s*=\s*"(.*)"',
   open('app/chavo.py').read(),
   re.M
   ).group(1)


with open("README.rst", "rb") as f:
   long_descr = f.read().decode("utf-8")

setup(
   name = "chavo",
   packages = find_packages(),
   entry_points = {
       "console_scripts": ['chavo = app.chavo:main']
       },
   version = version,
   description = "Command line html creator",
   long_description = long_descr,
   author = "Oscar Vazquez",
   author_email = "oscar.vazquez2012@gmail.com",
   url = "https://github.com/oscarvazquez/chavo"
)


import os
import sys
class main:
	def __init__(self):
		self.started = True

	def create_file(self):
		filename = raw_input("Filename? ")
		os.system('touch ' + filename)
		f = open(filename, 'w')
		return f

	def create_head(self, f, front_end=False):
		f.write("<!DOCTYPE html>\n")
		f.write("<html>\n")
		f.write("<head>\n")
		f.write("<meta charset='UTF-8'>")
		title = raw_input("Title? ")
		f.write("\t<title>" + title + "</title>\n")
		if front_end:
			if front_end == 'bootstrap':
				self.bootstrap(f)
			elif front_end == 'materialize':
				self.front_end(f)
			else:
				print 'only bootstrap and materialize for now'

		f.write("</head>\n")

	def create_bottom(self, f, front_end=False):
		if front_end:
			self.jquery(f)
			if front_end == 'bootstrap':
				self.bootstrapjs(f)
			elif front_end == 'materialize':
				self.materializejs(f)
		f.write("</body>\n")
		f.write("</html>")

	def bootstrap(self, f):
		f.write("\t<link rel='stylesheet' href='https://maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css' integrity='sha384-1q8mTJOASx8j1Au+a5WDVnPi2lkFfwwEAa8hDDdjZlpLegxhjVME1fgjWPGmkzs7' crossorigin='anonymous'>\n")
		self.front_end = "bootstrap"

	def materialize(self, f):
		f.write("\t<link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/materialize/0.97.5/css/materialize.css'>\n")
		self.front_end = "materialize"
	
	def foundation(self, f):
		f.write("\t<link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/foundation/6.1.1/foundation.css'>\n")
		self.front_end = "foundation"

	def jquery(self, f, front_end=False):
		f.write("\t<script src='https://cdnjs.cloudflare.com/ajax/libs/jquery/2.2.1/jquery.js'></script>\n")

	def bootstrapjs(self, f):
		f.write("\t<script src='https://maxcdn.bootstrapcdn.com/bootstrap/3.3.6/js/bootstrap.min.js'></script>\n")

	def materializejs(self, f):
		f.write("\t<script src='https://cdnjs.cloudflare.com/ajax/libs/materialize/0.97.5/js/materialize.min.js'></script>\n")

	def foundationjs(self, f):
		f.write("\t<script src = 'https://cdnjs.cloudflare.com/ajax/libs/foundation/6.2.0/foundation.min.js'></script>\n")
